#!/usr/bin/python
import hashlib
OUTPUT="keypadOS.lua";
FILES= [
    "updater.lua",
    "config.lua",
    "ui.lua",
    "utils.lua",
    "main.lua",
]

MINIMISE=True

def read_file(p: str) -> str:
    buf = "";
    with open("src/"+p, "r", encoding="utf-8") as f:
        buf += f"rawset(__BUNDLER_FILES, \"{p}\", function ()\n";
        for line in f.readlines():
            buf += "    " + line;
        buf += "\nend)";
        if not MINIMISE:
            buf += f"-- FILE END: {p} --\n";
        else:
            buf += "\n";
    return buf;

def minimise(buf: str) -> str:
    newbuf = "";
    for line in buf.splitlines():
        if line.strip().startswith("--"):
            continue;
        if line.strip() == "":
            continue
        newbuf += line + "\n";
    return newbuf;

def get_hash(buf: str) -> str:
    hasher = hashlib.sha1();

    hasher.update(bytes(buf, "utf-8"));
    return hasher.hexdigest();

REQ_HEADER = """
local __BUNDLER_FILES = {}
local __DEFAULT_IMPORT = require
local require = function(path)
    if __BUNDLER_FILES[path] then
        return __BUNDLER_FILES[path]()
    elseif __BUNDLER_FILES[path .. ".lua"] then
        return __BUNDLER_FILES[path .. ".lua"]()
    else
        return __DEFAULT_IMPORT(path)
    end
end
local __UPDATE_HASH = __BUNDLER_REPLACE_HASH__
"""

def main():
    buf = ""
    buf += REQ_HEADER; 
    for file in FILES:
        print(f"=== FILE: {file}");
        buf += read_file(file);
    
    buf += "return require(\"main.lua\")";

    if MINIMISE:
        buf = minimise(buf);
    update_hash = get_hash(buf);
    buf = buf.replace("__BUNDLER_REPLACE_HASH__", f"\"{update_hash}\"");

    print(f"=== UPDATE HASH: {update_hash}")
    with open(OUTPUT, "w", encoding="utf-8") as f:
        f.write(buf);
    print("DONE");

if __name__ == "__main__":
    main();

